import sys
from xml.sax import make_parser, handler
import string
import codecs
sizeMapping = {}
from xml.sax.saxutils import escape

class MyHandler(handler.ContentHandler):

    def __init__(self, out = sys.stdout):
        handler.ContentHandler.__init__(self)
        self._out = out

        self._text = ""
        self._parent = None
        self._list_started = 0
        self._title = None
        self._link = None
        self._descr = ""
        self._sizeMapping = sizeMapping

    # ContentHandler methods

    def startElement(self, name, attrs):
        if name == "Labels":
            self._brand = attrs['name']

        self._text = ""

    def endElement(self, name):
        if name == "Measure":
          continuous, self._horiz, self._vert, self._width, self._height, self._left, self._top, self._columns, self._rows = self._text.split(';')
          self._continuous = continuous == 'C' and 'Y' or 'N'
          self._sizeMatrix = self._text

        elif name == 'Name':
          self._name = self._text

        elif name == 'LabelType':

#          print self._brand, self._name
          addition = ( {'brand': escape(self._brand),
                        'horizontalspacing': str(float(self._horiz) / 1000) + 'cm',
                        'verticalspacing': str(float(self._vert) / 1000) + 'cm',
                        'labelwidth': str(float(self._width) / 1000) + 'cm',
                        'labelheight': str(float(self._height) / 1000) + 'cm',
                        'leftmargin': str(float(self._left) / 1000) + 'cm',
                        'topmargin': str(float(self._top) / 1000) + 'cm',
                        'columns': int(self._columns or "1") or 1,
                        'rows': int(self._rows or "1") or 1,
                        'part': string.split(self._name)[0],
                        'continuous': self._continuous,
                        'description': string.replace(escape(string.join(string.split(self._name)[1:], ' ')),'"','\\"') } )

          try:
            self._sizeMapping[self._sizeMatrix].append(addition)
          except KeyError:
            self._sizeMapping[self._sizeMatrix] = [addition]

    def characters(self, content):
        self._text = self._text + content

# --- Main program

parser = make_parser()
parser.setContentHandler(MyHandler())
parser.parse('import.xml')

outfile = codecs.open("export.xml",'w',encoding="utf-8")

outfile.write('<?xml version="1.0" encoding="utf-8"?>\n')
outfile.write("<labeldefs>\n")
index = 0
for sizemap in sizeMapping.keys():
  stuff = sizeMapping[sizemap][0]
  stuff['index'] = index
  outfile.write("""  <labeldef name="Label%(index)s" continuous="%(continuous)s" columns="%(columns)s" rows="%(rows)s"
            labelwidth="%(labelwidth)s" labelheight="%(labelheight)s" 
            leftmargin="%(leftmargin)s" topmargin="%(topmargin)s"
            horizontalspacing="%(horizontalspacing)s" verticalspacing="%(verticalspacing)s"
            insideleftmargin="0" insiderightmargin="0"
            insidetopmargin="0" insidebottommargin="0">\n""" % stuff)

  for stuff in sizeMapping[sizemap]:
    outfile.write('    <alias brand="%(brand)s" part="%(part)s" description="%(description)s"/>\n' % stuff)

  outfile.write("  </labeldef>\n")
  index += 1


outfile.write("</labeldefs>\n")
outfile.close()
