#!/usr/bin/env python
#
# Copyright 2001-2002 Free Software Foundation
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#

import sys
import string
import os
import os.path

from src import VERSION

try:
  import py2exe
except:
  pass


#
# hack to deal w/ fact distutils won't
# allow us to set absolute path prefix
# on windows
#

if not 'sdist' in sys.argv:
  if sys.platform != 'win32':
    os.system ("""cp setup.cfg.in setup.cfg""")
  else:
    try:
      os.remove('setup.cfg')
    except:
      pass





try:
  from distutils.core import setup
  from distutils.command.build_scripts import build_scripts
except ImportError:
  print """
Setup requires that python's distutils be
installed.  You can get a copy of it from
http://www.python.org/sigs/distutils-sig/
    """
  sys.exit()


if 'sdist' in sys.argv:
  print """
*** Notes for creating source disto ***

Make sure and create update the html and text docs
prior to creating the source distribution.
"""
  raw_input ("Press Control-D to abort or any other key to continue")

  os.system ("""
cd doc
lyx --export text ReportingConcepts.lyx
lyx --export pdf ReportingConcepts.lyx
""")


  print "Now, we are going to create the man pages for our tools."
  os.system( """
if [ ! -e man ]
then
mkdir man
fi
cd man
../scripts/grcvs --generate-man-page
#../scripts/gnue-reports-server --generate-man-page
""")


# Site config stuff
try:
  index = sys.argv.index('--cfg-file')
  site_config = os.path.join(os.path.abspath(sys.argv[index+1]))
  sys.argv.pop(index)
  sys.argv.pop(index)
  config_line = "os.environ['GNUE_INSTALLED_SITE_CFG']='%s'\n" % site_config

except ValueError:
  config_line = ""

#if ('build' in sys.argv) or ('install' in sys.argv):
#  # Verify that gnue-common is installed
#  try:
#    print "Checking for GNUe-Common....",
#    from gnue import common
#    if common.__dict__.has_key('VERSION'):
#      print "OK (version %s)" % common.VERSION
#    else:
#      print "OK"
#  except ImportError:
#    print """
#You will need to install gnue-common
#before gnuef will function.  You can
#obtain a copy from
#
#http://www.gnuenterprise.org/download.php
#"""
#    sys.exit()



class my_build_scripts(build_scripts):
  def finalize_options(self):

    build_scripts.finalize_options(self)

    if self.finalized:
      return


    if sys.platform != 'win32':
      dict = self.distribution.get_option_dict("install")
      install_prefix = dict['prefix'][1]

      gnue_env = \
           "#######\n" \
         + "# The following variable were set when GNUe was installed\n" \
         + "import os, sys\n" \
         + "sys.path.append('%s')\n" % dict['install_lib'][1] \
         + "INST_GNUE_CONNECTIONS='%s/etc/connections.conf'\n" % dict['prefix'][1] \
         + "os.environ['INSTALL_LIB']='%s'\n" % dict['install_lib'][1] \
         + "os.environ['INSTALL_PREFIX']='%s'\n" % dict['prefix'][1] \
         + config_line \
         + "#######\n"
    else:
      gnue_env = \
               "#######\n" \
             + "# The following variables were set when GNUe was installed\n"    \
             + "# (Generated for a Win32 system)\n" \
             + "import os, sys\n" \
             + "if __name__ == '__main__': \n" \
             + "  _BASE = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]),'..'))\n" \
             + "  try:\n" \
             + "    os.environ['PATH']= os.path.abspath(os.path.dirname(sys.argv[0])) + ';' + os.environ['PATH']\n" \
             + "  except KeyError:\n" \
             + "    os.environ['PATH']= os.path.abspath(os.path.dirname(sys.argv[0]))\n" \
             + "else: \n" \
             + "  _BASE = os.path.abspath(os.path.join(os.path.dirname(__file__),'..'))\n" \
             + "INST_GNUE_CONNECTIONS=os.path.join(_BASE,'etc','connections.conf')\n" \
             + "os.environ['INSTALL_PREFIX']=_BASE\n"                \
             + "os.environ['INSTALL_LIB']=_BASE\n"                   \
             + "os.putenv('PYTHONCASEOK','1')\n" \
             + config_line \
             + "if os.path.isdir(os.path.join(_BASE,'extras')):\n" \
             + "  sys.path.append(os.path.join(_BASE,'extras'))\n" \
             + "#######\n\n"

    for script in self.scripts:
      print "Building %s..."% (script),


      fin = open(script+".in", "r")
      fout = open(script, "w")

      print "Generating script %s from %s.in" % (script,script)

      lines = fin.readlines()

      for i in range(0, len(lines)):
        if string.strip(lines[i]) == "__GNUEENV__":
          lines[i] = gnue_env

      fout.writelines(lines)
      fin.close()
      fout.close()
      print "OK"


docfiles = []
for file in ('doc/ReportingConcepts.txt',
             'doc/ReportingConcepts.pdf'):
  if os.path.isfile(file):
    docfiles.append(file)
  else:
    print "WARNING: File %s does not exist... not installing!" % file

manfiles = []
for file in ('man/gnue-reports.1',
             'man/gnue-reports-server.1'):
  if os.path.isfile(file):
    manfiles.append(file)
  else:
    print "WARNING: File %s does not exist... not installing!" % file


#
# You can run:
#   $ GNUE_VERSION_SUFFIX=-pre1 ./setup.py sdist
# and the packages will be created as GNUe-App-0.x.x-pre1.tar.gz
#
try:
  suffix = os.environ['GNUE_VERSION_SUFFIX']
except KeyError:
  suffix = ""


setup (name = "GNUe-Reports",
       version = VERSION+suffix,
       description = "GNU Enterprise Reports",
       long_description = "",
       author = "GNUe Reports Team",
       author_email = "info@gnue.org",
       url = "http://www.gnue.org",

       # Override certain command classes with our own ones
       cmdclass = {'build_scripts':my_build_scripts},

       data_files = [ ('doc/reports', docfiles),
                      ('man/man1', manfiles),
                      ('shared/filters',['filters/README']),
                      ('shared/filters/SimpleTabulation', [
                                      'filters/SimpleTabulation/csv.xsl',
                                      'filters/SimpleTabulation/html.xsl',
                                      'filters/SimpleTabulation/text.xsl']
                       ) ],

       packages = ["gnue.reports",
                   "gnue.reports.adapters",
                   "gnue.reports.adapters.filters",
                   "gnue.reports.adapters.filters.sablotron",
                   "gnue.reports.adapters.filters.4xslt",
                   "gnue.reports.adapters.filters.raw",
                   "gnue.reports.adapters.filters.labels",
                   "gnue.reports.adapters.filters.labels.formatters",
                   "gnue.reports.adapters.filters._merge",
                   "gnue.reports.adapters.filters.merge_latex",
                   "gnue.reports.adapters.filters.merge_rtf",
                   "gnue.reports.adapters.filters.merge_ps",
                   "gnue.reports.adapters.destinations",
                   "gnue.reports.adapters.destinations.email",
                   "gnue.reports.adapters.destinations.fax",
                   "gnue.reports.adapters.destinations.file",
                   "gnue.reports.adapters.destinations.printer"],

       package_dir = {"gnue.reports" : "src"},

       scripts = ["scripts/gnue-reports", "scripts/gnue-reports-server"]
       )

if 'install' in sys.argv:
    print """
    Note:
    Warnings about the files not being installed in pythons search path can be ignored.

    Make sure you have a default gnue.conf file (typically in /usr/local/gnue/etc.
    A sample is provided in that directory that you can typically just copy over.
    """

if not 'sdist' in sys.argv:
  if sys.platform != 'win32':
    os.system (""" /bin/rm -rf setup.cfg""")
